namespace AziendaBibite;

class Program
{
    static void Main(string[] args)
    {
        Azienda azienda = new Azienda("XYZ");
        azienda.AggiungiBevanda(
            new BevandaAlcolica("Birra", "Acqua, Malto, Luppolo, Lievito", 50, 5),
            new BevandaAlcolica("Vino Rosso", "Uva", 30, 13),
            new BevandaAlcolica("Whiskey", "Orzo, Acqua", 20, 40),
            new BevandaAlcolica("Rum", "Zucchero di canna, Lievito", 25, 37),
            new BevandaAlcolica("Vodka", "Patate, Acqua", 15, 40),
            new BevandaAnalcolica("Coca Cola", "Acqua, Zucchero, Caffeina, Caramello", 100, true),
            new BevandaAnalcolica("Succo di Arancia", "Arance", 80, false),
            new BevandaAnalcolica("Acqua Minerale", "Acqua", 200, false),
            new BevandaAnalcolica("Fanta", "Acqua, Zucchero, Aromi, C02", 60, true),
            new BevandaAnalcolica("Tè Freddo", "Acqua, Tè, Zucchero, Limone", 70, true));

        azienda.AggiungiCliente(
            new Cliente("S.n.c", "Via Roma 1", "Milano", "Lombardia"),
            new Cliente("S.n.c", "Via Roma 2", "Milano", "Lombardia"),
            new Cliente("S.n.c", "Via Roma 3", "Milano", "Lombardia"),
            new Cliente("S.n.c", "Via Roma 4", "Milano", "Lombardia")
            );
        
        azienda.RegistraVendita(
            new Vendita(0, 0, 2),
            new Vendita(2, 6, 1),
            new Vendita(3, 8, 3),
            new Vendita(1, 2, 5),
            new Vendita(0, 4, 1),
            new Vendita(2, 7, 2),
            new Vendita(1, 1, 4),
            new Vendita(3, 2, 1));
        
        Console.WriteLine(azienda.Info());
        
        Console.WriteLine("Vendite:");
        Console.WriteLine(azienda.InfoVendite());
        
        Console.Write("Inserisci codice cliente da controllare: ");
        int cliente;
        while (!int.TryParse(Console.ReadLine(), out cliente))
        {
            Console.Write("Errore di tipo: ");
        }
        Console.Write("Bevande acquistate dal cliente '{0}': ", cliente);
        Console.WriteLine(azienda.BevandeAcquistateDa(cliente));
        
        Console.Write("Inserisci ingrediente da controllare: ");
        string ingrediente = Console.ReadLine();
        Console.WriteLine("Bevande con ingrediente '{0}':", ingrediente);
        Console.WriteLine(azienda.BibiteIngrediente(ingrediente));
    }
}